AdvancedColumn class

A column that have additional properties. It's a wrapper around Column and adds additional properties.

Inheritance

Constructors

AdvancedColumn({Key? key, AlignmentGeometry? alignment, EdgeInsetsGeometry? padding, Decoration? decoration, Decoration? foregroundDecoration, double? width, double? height, BoxConstraints? constraints, EdgeInsetsGeometry? margin, Matrix4? transform, AlignmentGeometry? transformAlignment, List<Widget> children = const [], Clip clipBehavior = Clip.none, Widget gapWidget = const SizedBox(height: 0, width: 0), MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, MainAxisSize mainAxisSize = MainAxisSize.max, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, TextBaseline? textBaseline})
const

Properties

alignment → AlignmentGeometry?
The alignment of the column.
final
children → List<Widget>
The children of the column.
final
clipBehavior → Clip
The clip behavior of the column.
final
constraints → BoxConstraints?
The constraints of the column.
final
crossAxisAlignment → CrossAxisAlignment
The cross axis alignment of the column.
final
decoration → Decoration?
Background decoration of the column.
final
foregroundDecoration → Decoration?
Foreground decoration of the column.
final
gapWidget → Widget
The gap widget between the children. Important: This will not add the widget to the top most and bottom most of the column.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
The height of the column.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisAlignment → MainAxisAlignment
The main axis alignment of the column.
final
mainAxisSize → MainAxisSize
The main axis size of the column.
final
margin → EdgeInsetsGeometry?
The margin of the column.
final
padding → EdgeInsetsGeometry?
The padding of the column.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textBaseline → TextBaseline?
The text baseline of the column.
final
textDirection → TextDirection?
The text direction of the column.
final
transform → Matrix4?
The transform of the column.
final
transformAlignment → AlignmentGeometry?
The alignment of the transform.
final
verticalDirection → VerticalDirection
The vertical direction of the column.
final
width → double?
The width of the column.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited